@@ -1,22 +1,17 @@
-#  Copyright (C) 2021 Xilinx, Inc
+# Copyright (C) 2021 Xilinx, Inc
 #
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-
+# SPDX-License-Identifier: Apache-2.0
 
+# Since Vitis AI 1.4, vart.so is located in /usr/lib/python3/site-packages
 import sys
-if '/usr/lib/python3.6/site-packages' not in sys.path:
-    sys.path.append('/usr/lib/python3.6/site-packages')
+if '/usr/lib/python3/site-packages' not in sys.path:
+    sys.path.append('/usr/lib/python3/site-packages')
 
+# Notify user if vart can't be found
+try:
+    import vart
+except:
+    print("Couldn't import vart, check if library installed and is on path.")
 
 import os
 import subprocess
@@ -26,16 +21,32 @@ import pynq
 import vart
 import xir
 
-
-__author__ = "Yun Rock Qu, Jingwei Zhang"
-__copyright__ = "Copyright 2021, Xilinx"
-__email__ = "pynq_support@xilinx.com"
-
-
 MODULE_PATH = os.path.dirname(os.path.realpath(__file__))
-OVERLAY_PATH = os.path.join(MODULE_PATH, 'overlays')
+OVERLAY_PATH = MODULE_PATH
 XCL_DST_PATH = "/usr/lib"
 
+# If the vart.conf file is not set to correctly reflect the firmware you may experience 
+# board crashes. Other DPU applications may overwrite this directory to point to a custom 
+# firmware location. When working on DPU applications outside of pynq_dpu, make sure you
+# set vart.conf to the correct location for your application.
+def check_vart_config():
+    """ VART config check
+    
+    Check the vart config file located in /etc/vart.conf, the dpu.xclin which is part
+    of this package gets installed in /usr/lib/dpu.xclbin. If the config is set to a different
+    firmware location than expected, it gets overwritten to the default of this package.
+    
+    """
+    with open('/etc/vart.conf') as txt:
+        # Read vart.conf contents
+        previous_firmware = txt.readline()
+
+        # If existing configuration is not expected, replace to default location
+        if '/usr/lib/dpu.xclbin' not in previous_firmware:
+            print("/etc/vart.conf file was modified, replacing contents '{}' with '{}'.".format(previous_firmware.strip('\n').split(' ')[1], '/usr/lib/dpu.xclbin'))
+
+    with open('/etc/vart.conf', 'w') as txt:
+        txt.write('firmware: /usr/lib/dpu.xclbin')
 
 def get_child_subgraph_dpu(graph: "Graph"):
     assert graph is not None, \
@@ -66,7 +77,7 @@ class DpuOverlay(pynq.Overlay):
         Check PYNQ overlay class for more information on parameters.
 
         By default, the bit file will be searched in the following paths:
-        (1) the `overlays` folder inside this module; (2) an absolute path;
+        (1) inside this module; (2) an absolute path;
         (3) the relative path of the current working directory.
 
         By default, this class will set the runtime to be `dnndk`.
@@ -105,7 +116,7 @@ class DpuOverlay(pynq.Overlay):
         """Copy the xclbin file to a specific location.
 
         This method will copy the xclbin file into the destination directory to
-        make sure DNNDK libraries can work without problems.
+        make sure VART libraries can work without problems.
 
         The xclbin file, if not set explicitly, is required to be located
         in the same folder as the bitstream and hwh files.
@@ -126,24 +137,13 @@ class DpuOverlay(pynq.Overlay):
                                      abs_xclbin, XCL_DST_PATH])
 
     def load_model(self, model):
-        """Load DPU models for both DNNDK runtime and VART.
-
-        For DNNDK, this method will compile the ML model `*.elf` binary file,
-        compile it into `*.so` file located in the destination directory
-        on the target. This will make sure DNNDK libraries can work
-        without problems.
+        """Load DPU models for VART.
 
         The ML model file, if not set explicitly, is required to be located
         in the same folder as the bitstream and hwh files.
-
-        The destination folder by default is `/usr/lib`.
-
-        Currently only `*.elf` files are supported as models. The reason is
-        that `*.so` usually have to be recompiled targeting a specific
-        rootfs.
-
-        For VART, this method will automatically generate the `meta.json` file
-        in the same folder as the model file.
+        
+        This also creates a vart.Runner instance, used to communicate wtih the
+        vart API.
 
         Parameters
         ----------
@@ -151,6 +151,7 @@ class DpuOverlay(pynq.Overlay):
             The name of the ML model binary. Can be absolute or relative path.
 
         """
+        check_vart_config() # make sure that vart.conf is pointing to the right firmware dir
         if os.path.isfile(model):
             abs_model = model
         elif os.path.isfile(self.overlay_dirname + "/" + model):
